@@ -1,3 +1,4 @@
+import copy
 import re
 import warnings
 
@@ -41,7 +42,6 @@ Features requiring DataShader will not work and you will get exceptions."""
 
 from . import utils
 from . import image
-from . import az_utils
 
 try:
     from . import stan
@@ -1279,7 +1279,9 @@ def parcoord(
     samples=None,
     parameters=None,
     palette=None,
-    omit=re.compile("(.*_ppc\[?\d*\]?$)|(log_?lik.*\[?\d*\]?$)"),
+    omit=None,
+    include_ppc=False,
+    include_log_lik=False,
     transformation=None,
     color_by_chain=False,
     line_kwargs={},
@@ -1300,6 +1302,9 @@ def parcoord(
         Names of parameters to include in the plot. If None, use all
         parameters. For multidimensional parameters, each entry must be
         given separately, e.g., `['alpha[0]', 'alpha[1]', 'beta[0,1]']`.
+        If a given entry is a 2-tuple, the first entry is the variable
+        name, and the second entry is the label for the parameter in
+        plots.
     palette : list of strings of hex colors, or single hex string
         If a list, color palette to use. If a single string representing
         a hex color, all glyphs are colored with that color. Default is
@@ -1307,13 +1312,16 @@ def parcoord(
     omit : str, re.Pattern, or list or tuple of str and re.Pattern
         If `parameters` is not provided, all parameters are used in the
         parallel coordinate plot. We often want to ignore samples of
-        posterior predictive checks, log likelihoods, and other
-        generated quantities. For each string entry in `omit`, the
-        variable given by the string is omitted. For each entry that is
-        a compiled regular expression patters (`re.Pattern`), any
-        variable name matching the pattern is omitted. By default, any
-        variable that ends in '_ppc' and any variable beginning with
-        'log_lik' or 'loglik' are ignored.
+        some variables. For each string entry in `omit`, the variable
+        given by the string is omitted. For each entry that is a
+        compiled regular expression patters (`re.Pattern`), any variable
+        name matching the pattern is omitted.
+    include_ppc : bool, default False
+        If True, include variables ending in _ppc, which denotes
+        posterior predictive checks, in the plot.
+    include_log_lik: bool, default False
+        If True, include variables starting with log_lik or loglik.
+        These denote log-likelihood contributions.
     transformation : function, str, or dict, default None
         A transformation to apply to each set of samples. The function
         must take a single array as input and return an array as the
@@ -1344,8 +1352,10 @@ def parcoord(
         Parallel coordinates plot.
 
     """
-    if type(omit) not in [tuple, list]:
-        omit = [omit]
+    if parameters is not None and omit is not None:
+        raise RuntimeError("At least one of `parameters` and `omit` must be None.")
+
+    omit = _parse_omit(omit, include_ppc, include_log_lik)
 
     # Default properties
     if palette is None:
@@ -1387,29 +1397,31 @@ def parcoord(
         warnings.warn("No divergence information available.")
 
     parameters, df = stan._samples_parameters_to_df(samples, parameters, omit)
+    parameters, labels = _parse_parameters(parameters)
+    df.rename(columns={param: label for param, label in zip(parameters, labels)})
 
     if transformation == "minmax":
         transformation = {
             param: lambda x: (x - x.min()) / (x.max() - x.min())
             if x.min() < x.max()
             else 0.0
-            for param in parameters
+            for param in labels
         }
     elif transformation == "rank":
-        transformation = {param: lambda x: st.rankdata(x) for param in parameters}
+        transformation = {param: lambda x: st.rankdata(x) for param in labels}
 
     if transformation is None:
-        transformation = {param: lambda x: x for param in parameters}
+        transformation = {param: lambda x: x for param in labels}
 
     if callable(transformation) or transformation is None:
-        transformation = {param: transformation for param in parameters}
+        transformation = {param: transformation for param in labels}
 
     for col, trans in transformation.items():
         df[col] = trans(df[col])
-    df = df.melt(id_vars=["divergent__", "chain__", "draw__"])
+    df = df.melt(id_vars=["diverging__", "chain__", "draw__"])
 
     p = bokeh.plotting.figure(
-        x_range=bokeh.models.FactorRange(*parameters),
+        x_range=bokeh.models.FactorRange(*labels),
         toolbar_location=toolbar_location,
         **kwargs,
     )
@@ -1418,7 +1430,7 @@ def parcoord(
     ys = np.array(
         [
             group["value"].values
-            for _, group in df.loc[~df["divergent__"]].groupby(["chain__", "draw__"])
+            for _, group in df.loc[~df["diverging__"]].groupby(["chain__", "draw__"])
         ]
     )
     if len(ys) > 0:
@@ -1439,7 +1451,7 @@ def parcoord(
     ys = np.array(
         [
             group["value"].values
-            for _, group in df.loc[df["divergent__"]].groupby(["chain__", "draw__"])
+            for _, group in df.loc[df["diverging__"]].groupby(["chain__", "draw__"])
         ]
     )
     if len(ys) > 0:
@@ -1465,7 +1477,9 @@ def trace(
     samples=None,
     parameters=None,
     palette=None,
-    omit=re.compile("(.*_ppc\[?\d*\]?$)|(log_?lik.*\[?\d*\]?$)"),
+    omit=None,
+    include_ppc=False,
+    include_log_lik=False,
     line_kwargs={},
     **kwargs,
 ):
@@ -1480,20 +1494,26 @@ def trace(
         Names of parameters to include in the plot. If None, use all
         parameters. For multidimensional parameters, each entry must be
         given separately, e.g., `['alpha[0]', 'alpha[1]', 'beta[0,1]']`.
+        If a given entry is a 2-tuple, the first entry is the variable
+        name, and the second entry is the label for the parameter in
+        plots.
     palette : list of strings of hex colors, or single hex string
         If a list, color palette to use. If a single string representing
         a hex color, all glyphs are colored with that color. Default is
         colorcet.b_glasbey_category10 from the colorcet package.
     omit : str, re.Pattern, or list or tuple of str and re.Pattern
         If `parameters` is not provided, all parameters are used in the
-        trace plot. We often want to ignore samples of posterior
-        predictive checks, log likelihoods, and other generated
-        quantities. For each string entry in `omit`, the variable given
-        by the string is omitted. For each entry that is a compiled
-        regular expression pattern (`re.Pattern`), any variable name
-        matching the pattern is omitted. By default, any variable that
-        ends in '_ppc' and any variable beginning with 'log_lik' or
-        'loglik' are ignored.
+        parallel coordinate plot. We often want to ignore samples of
+        some variables. For each string entry in `omit`, the variable
+        given by the string is omitted. For each entry that is a
+        compiled regular expression patters (`re.Pattern`), any variable
+        name matching the pattern is omitted.
+    include_ppc : bool, default False
+        If True, include variables ending in _ppc, which denotes
+        posterior predictive checks, in the plot.
+    include_log_lik: bool, default False
+        If True, include variables starting with log_lik or loglik.
+        These denote log-likelihood contributions.
     line_kwargs: dict
         Dictionary of kwargs to be passed to `p.multi_line()` in making
         the plot of non-divergent samples.
@@ -1505,8 +1525,10 @@ def trace(
     output : Bokeh gridplot
         Set of chain traces as a Bokeh gridplot.
     """
-    if type(omit) not in [tuple, list]:
-        omit = [omit]
+    if parameters is not None and omit is not None:
+        raise RuntimeError("At least one of `parameters` and `omit` must be None.")
+
+    omit = _parse_omit(omit, include_ppc, include_log_lik)
 
     if type(samples) != az.data.inference_data.InferenceData:
         raise RuntimeError("Input must be an ArviZ InferenceData instance.")
@@ -1515,6 +1537,7 @@ def trace(
         raise RuntimeError("Input samples do not have 'posterior' group.")
 
     parameters, df = stan._samples_parameters_to_df(samples, parameters, omit)
+    parameters, labels = _parse_parameters(parameters)
 
     # Default properties
     if palette is None:
@@ -1541,8 +1564,10 @@ def trace(
 
     plots = []
     grouped = df.groupby("chain__")
-    for i, var in enumerate(parameters):
-        p = bokeh.plotting.figure(x_axis_label=x_axis_label, y_axis_label=var, **kwargs)
+    for i, (var, label) in enumerate(zip(parameters, labels)):
+        p = bokeh.plotting.figure(
+            x_axis_label=x_axis_label, y_axis_label=label, **kwargs
+        )
         for i, (chain, group) in enumerate(grouped):
             p.line(
                 group["draw__"],
@@ -1569,12 +1594,13 @@ def corner(
     samples=None,
     parameters=None,
     palette=None,
-    omit=re.compile("(.*_ppc\[?\d*\]?$)|(log_?lik.*\[?\d*\]?$)"),
-    labels=None,
+    omit=None,
+    include_ppc=False,
+    include_log_lik=False,
     max_plotted=10000,
     datashade=False,
-    frame_width=150,
-    frame_height=150,
+    frame_width=None,
+    frame_height=None,
     plot_ecdf=False,
     ecdf_staircase=False,
     cmap="black",
@@ -1610,11 +1636,9 @@ def corner(
         InferenceData instance, `parameters` contains the names of
         parameters to include in the  plot. For multidimensional
         parameters, each entry must be given separately, e.g.,
-        `['alpha[0]', 'alpha[1]', 'beta[0,1]']`.
-    labels : list, default None
-        List of labels for the respective variables given in
-        `parameters`. If None, the variable names from `parameters` are
-        used.
+        `['alpha[0]', 'alpha[1]', 'beta[0,1]']`. If a given entry is a
+        2-tuple, the first entry is the variable name, and the second
+        entry is the label for the parameter in plots.
     palette : list of strings of hex colors, or single hex string
         If a list, color palette to use. If a single string representing
         a hex color, all glyphs are colored with that color. Default is
@@ -1622,23 +1646,31 @@ def corner(
         `color_by_chain` is False.
     omit : str, re.Pattern, or list or tuple of str and re.Pattern
         If `parameters` is not provided, all parameters are used in the
-        corner plot. We often want to ignore samples of posterior
-        predictive checks, log likelihoods, and other generated
-        quantities. For each string entry in `omit`, the variable given
-        by the string is omitted. For each entry that is a compiled
-        regular expression pattern (`re.Pattern`), any variable name
-        matching the pattern is omitted. By default, any variable that
-        ends in '_ppc' and any variable beginning with 'log_lik' or
-        'loglik' are ignored.
+        parallel coordinate plot. We often want to ignore samples of
+        some variables. For each string entry in `omit`, the variable
+        given by the string is omitted. For each entry that is a
+        compiled regular expression patters (`re.Pattern`), any variable
+        name matching the pattern is omitted.
+    include_ppc : bool, default False
+        If True, include variables ending in _ppc, which denotes
+        posterior predictive checks, in the plot.
+    include_log_lik: bool, default False
+        If True, include variables starting with log_lik or loglik.
+        These denote log-likelihood contributions.
     max_plotted : int, default 10000
         Maximum number of points to be plotted.
     datashade : bool, default False
         Whether or not to convert sampled points to a raster image using
         Datashader.
-    frame_width : int, default 150
-        Width of each plot in the corner plot in pixels.
-    frame_height : int, default 150
-        Height of each plot in the corner plot in pixels.
+    frame_width : int or None, default None
+        Width of each plot in the corner plot in pixels. Default is set
+        based on number of parameters plotted. If None and
+        `frame_height` is specificed, `frame_width` is set to
+        `frame_height`.
+    frame_height : int or None, default None
+        Height of each plot in the corner plot in pixels. Default is set
+        based on number of parameters plotted. If None and `frame_width`
+        is specificed, `frame_height` is set to `frame_width`.
     plot_ecdf : bool, default False
         If True, plot ECDFs of samples on the diagonal of the corner
         plot. If False, histograms are plotted.
@@ -1697,8 +1729,10 @@ def corner(
     output : Bokeh gridplot
         Corner plot as a Bokeh gridplot.
     """
-    if type(omit) not in [tuple, list]:
-        omit = [omit]
+    if parameters is not None and omit is not None:
+        raise RuntimeError("At least one of `parameters` and `omit` must be None.")
+
+    omit = _parse_omit(omit, include_ppc, include_log_lik)
 
     # Datashading not implemented
     if datashade:
@@ -1721,22 +1755,43 @@ def corner(
     if type(samples) == pd.core.frame.DataFrame:
         df = samples
         if parameters is None:
-            parameters = [col for col in df.columns if len(col) < 2 or col[-2:] != "__"]
+            parameters = [
+                col
+                for col in df.columns
+                if stan._screen_param(col, omit) and (len(col) < 2 or col[-2:] != "__")
+            ]
     elif type(samples) == np.ndarray:
         if parameters is None:
             parameters = list(range(samples.shape[1]))
         for param in parameters:
-            if type(param) != int:
+            if (type(param) in [tuple, list] and type(param[0]) != int) or type(
+                param
+            ) != int:
                 raise RuntimeError(
                     "When `samples` is inputted as a Numpy array, `parameters` must be"
                     " a list of indices."
                 )
-        new_parameters = [str(param) for param in parameters]
+        new_parameters = [
+            str(param) if type(param) == int else param[1] for param in parameters
+        ]
         df = pd.DataFrame(samples[:, parameters], columns=new_parameters)
         parameters = new_parameters
     else:
         parameters, df = stan._samples_parameters_to_df(samples, parameters, omit)
 
+    parameters, labels = _parse_parameters(parameters)
+
+    # Set default frame width and height.
+    if frame_height is None:
+        if frame_width is None:
+            default_dim = 25 * (9 - len(parameters)) if len(parameters) < 5 else 100
+            frame_height = default_dim
+            frame_width = default_dim
+        else:
+            frame_height = frame_width
+    elif frame_width is None:
+        frame_width = frame_height
+
     if len(parameters) > 6:
         raise RuntimeError("For space purposes, can show only six parameters.")
 
@@ -1748,9 +1803,9 @@ def corner(
         cmap = bokeh.transform.factor_cmap("chain__", palette=palette, factors=factors)
 
     # Add dummy divergent column if no divergence information is given
-    if "divergent__" not in df.columns:
+    if "diverging__" not in df.columns:
         df = df.copy()
-        df["divergent__"] = 0
+        df["diverging__"] = 0
 
     # Add dummy chain column if no divergence information is given
     if "chain__" not in df.columns:
@@ -1770,13 +1825,13 @@ def corner(
         for param in parameters:
             df[f"__ECDF_{param}"] = df[param].rank(method="first") / len(df)
 
-    n_nondivergent = np.sum(df["divergent__"] == 0)
+    n_nondivergent = np.sum(df["diverging__"] == 0)
     if n_nondivergent > max_plotted:
         inds = np.random.choice(
             np.arange(n_nondivergent), replace=False, size=max_plotted
         )
     else:
-        inds = np.arange(np.sum(df["divergent__"] == 0))
+        inds = np.arange(np.sum(df["diverging__"] == 0))
 
     if alpha is None:
         if len(inds) < 100:
@@ -1787,8 +1842,8 @@ def corner(
             alpha = np.exp(-(np.log10(len(inds)) - 2) / (-2 / np.log(0.02)))
 
     # Set up column data sources to allow linked brushing
-    cds = bokeh.models.ColumnDataSource(df.loc[df["divergent__"] == 0, :].iloc[inds, :])
-    cds_div = bokeh.models.ColumnDataSource(df.loc[df["divergent__"] == 1, :])
+    cds = bokeh.models.ColumnDataSource(df.loc[df["diverging__"] == 0, :].iloc[inds, :])
+    cds_div = bokeh.models.ColumnDataSource(df.loc[df["diverging__"] == 1, :])
 
     # Just make a single plot if only one parameter
     if len(parameters) == 1:
@@ -2231,6 +2286,48 @@ def cdf_to_staircase(x, y):
     return x_staircase, y_staircase
 
 
+def _parse_omit(omit, include_ppc, include_log_lik):
+    """Determine which variables to omit in plot."""
+    if omit is None:
+        omit = []
+
+    if type(omit) == tuple:
+        omit = list(omit)
+
+    if type(omit) != list:
+        omit = [omit]
+    else:
+        omit = copy.copy(omit)
+
+    if not include_ppc:
+        if not include_log_lik:
+            omit += [re.compile("(.*_ppc\[?\d*\]?$)|(log_?lik.*\[?\d*\]?$)")]
+        else:
+            omit += [re.compile("(.*_ppc\[?\d*\]?$)")]
+    elif not include_log_like:
+        omit += [re.compile("(log_?lik.*\[?\d*\]?$)")]
+
+    return tuple(omit)
+
+
+def _parse_parameters(params):
+    parameters = []
+    labels = []
+    for param in params:
+        if type(param) in (tuple, list):
+            if len(param) != 2:
+                raise RuntimeError("f{param} is not a proper parameter specification.")
+            parameters.append(param[0])
+            labels.append(param[1])
+        elif type(param) == str:
+            parameters.append(param)
+            labels.append(param)
+        else:
+            raise RuntimeError("f{param} is not a proper parameter specification.")
+
+    return parameters, labels
+
+
 @numba.jit(nopython=True)
 def _y_ecdf(data, x):
     y = np.arange(len(data) + 1) / len(data)
@@ -2292,230 +2389,6 @@ def _ecdf_diff(data, L, staircase=False):
     return x, y
 
 
-def _get_cat_range(df, grouped, order, color_column, horizontal):
-    if order is None:
-        if isinstance(list(grouped.groups.keys())[0], tuple):
-            factors = tuple(
-                [tuple([str(k) for k in key]) for key in grouped.groups.keys()]
-            )
-        else:
-            factors = tuple([str(key) for key in grouped.groups.keys()])
-    else:
-        if type(order[0]) in [list, tuple]:
-            factors = tuple([tuple([str(k) for k in key]) for key in order])
-        else:
-            factors = tuple([str(entry) for entry in order])
-
-    if horizontal:
-        cat_range = bokeh.models.FactorRange(*(factors[::-1]))
-    else:
-        cat_range = bokeh.models.FactorRange(*factors)
-
-    if color_column is None:
-        color_factors = factors
-    else:
-        color_factors = tuple(sorted(list(df[color_column].unique().astype(str))))
-
-    return cat_range, factors, color_factors
-
-
-def _cat_figure(
-    df,
-    grouped,
-    plot_height,
-    plot_width,
-    x_axis_label,
-    y_axis_label,
-    title,
-    order,
-    color_column,
-    tooltips,
-    horizontal,
-    val_axis_type,
-):
-    fig_kwargs = dict(
-        plot_height=plot_height,
-        plot_width=plot_width,
-        x_axis_label=x_axis_label,
-        y_axis_label=y_axis_label,
-        title=title,
-        tooltips=tooltips,
-    )
-
-    cat_range, factors, color_factors = _get_cat_range(
-        df, grouped, order, color_column, horizontal
-    )
-
-    if horizontal:
-        fig_kwargs["y_range"] = cat_range
-        fig_kwargs["x_axis_type"] = val_axis_type
-    else:
-        fig_kwargs["x_range"] = cat_range
-        fig_kwargs["y_axis_type"] = val_axis_type
-
-    return bokeh.plotting.figure(**fig_kwargs), factors, color_factors
-
-
-def _cat_source(df, cats, cols, color_column):
-    if type(cats) in [list, tuple]:
-        cat_source = list(zip(*tuple([df[cat].astype(str) for cat in cats])))
-        labels = [", ".join(cat) for cat in cat_source]
-    else:
-        cat_source = list(df[cats].astype(str).values)
-        labels = cat_source
-
-    if type(cols) in [list, tuple, pd.core.indexes.base.Index]:
-        source_dict = {col: list(df[col].values) for col in cols}
-    else:
-        source_dict = {cols: list(df[cols].values)}
-
-    source_dict["cat"] = cat_source
-    if color_column in [None, "cat"]:
-        source_dict["__label"] = labels
-    else:
-        source_dict["__label"] = list(df[color_column].astype(str).values)
-        source_dict[color_column] = list(df[color_column].astype(str).values)
-
-    return bokeh.models.ColumnDataSource(source_dict)
-
-
-def _tooltip_cols(tooltips):
-    if tooltips is None:
-        return []
-    if type(tooltips) not in [list, tuple]:
-        raise RuntimeError("`tooltips` must be a list or tuple of two-tuples.")
-
-    cols = []
-    for tip in tooltips:
-        if type(tip) not in [list, tuple] or len(tip) != 2:
-            raise RuntimeError("Invalid tooltip.")
-        if tip[1][0] == "@":
-            if tip[1][1] == "{":
-                cols.append(tip[1][2 : tip[1].find("}")])
-            elif "{" in tip[1]:
-                cols.append(tip[1][1 : tip[1].find("{")])
-            else:
-                cols.append(tip[1][1:])
-
-    return cols
-
-
-def _cols_to_keep(cats, val, color_column, tooltips):
-    cols = _tooltip_cols(tooltips)
-    cols += [val]
-
-    if type(cats) in [list, tuple]:
-        cols += list(cats)
-    else:
-        cols += [cats]
-
-    if color_column is not None:
-        cols += [color_column]
-
-    return list(set(cols))
-
-
-def _check_cat_input(df, cats, val, color_column, tooltips, palette, kwargs):
-    if df is None:
-        raise RuntimeError("`df` argument must be provided.")
-    if cats is None:
-        raise RuntimeError("`cats` argument must be provided.")
-    if val is None:
-        raise RuntimeError("`val` argument must be provided.")
-
-    if type(palette) not in [list, tuple]:
-        raise RuntimeError("`palette` must be a list or tuple.")
-
-    if val not in df.columns:
-        raise RuntimeError(f"{val} is not a column in the inputted data frame")
-
-    cats_array = type(cats) in [list, tuple]
-
-    if cats_array:
-        for cat in cats:
-            if cat not in df.columns:
-                raise RuntimeError(f"{cat} is not a column in the inputted data frame")
-    else:
-        if cats not in df.columns:
-            raise RuntimeError(f"{cats} is not a column in the inputted data frame")
-
-    if color_column is not None and color_column not in df.columns:
-        raise RuntimeError(f"{color_column} is not a column in the inputted data frame")
-
-    cols = _cols_to_keep(cats, val, color_column, tooltips)
-
-    for col in cols:
-        if col not in df.columns:
-            raise RuntimeError(f"{col} is not a column in the inputted data frame")
-
-    bad_kwargs = ["x", "y", "source", "cat", "legend"]
-    if kwargs is not None and any([key in kwargs for key in bad_kwargs]):
-        raise RuntimeError(", ".join(bad_kwargs) + " are not allowed kwargs.")
-
-    if val == "cat":
-        raise RuntimeError("`'cat'` cannot be used as `val`.")
-
-    if val == "__label" or (cats == "__label" or (cats_array and "__label" in cats)):
-        raise RuntimeError("'__label' cannot be used for `val` or `cats`.")
-
-    return cols
-
-
-def _outliers(data):
-    bottom, middle, top = np.percentile(data, [25, 50, 75])
-    iqr = top - bottom
-    outliers = data[(data > top + 1.5 * iqr) | (data < bottom - 1.5 * iqr)]
-    return outliers
-
-
-def _box_and_whisker(data):
-    middle = data.median()
-    bottom = data.quantile(0.25)
-    top = data.quantile(0.75)
-    iqr = top - bottom
-    top_whisker = data[data <= top + 1.5 * iqr].max()
-    bottom_whisker = data[data >= bottom - 1.5 * iqr].min()
-    return pd.Series(
-        {
-            "middle": middle,
-            "bottom": bottom,
-            "top": top,
-            "top_whisker": top_whisker,
-            "bottom_whisker": bottom_whisker,
-        }
-    )
-
-
-def _box_source(df, cats, val, cols):
-    """Construct a data frame for making box plot."""
-
-    # Need to reset index for use in slicing outliers
-    df_source = df.reset_index(drop=True)
-
-    if type(cats) in [list, tuple]:
-        level = list(range(len(cats)))
-    else:
-        level = 0
-
-    if cats is None:
-        grouped = df_source
-    else:
-        grouped = df_source.groupby(cats)
-
-    # Data frame for boxes and whiskers
-    df_box = grouped[val].apply(_box_and_whisker).unstack().reset_index()
-    source_box = _cat_source(
-        df_box, cats, ["middle", "bottom", "top", "top_whisker", "bottom_whisker"], None
-    )
-
-    # Data frame for outliers
-    df_outliers = grouped[val].apply(_outliers).reset_index(level=level)
-    df_outliers[cols] = df_source.loc[df_outliers.index, cols]
-    source_outliers = _cat_source(df_outliers, cats, cols, None)
-
-    return source_box, source_outliers
-
-
 def _ecdf_y(data, complementary=False):
     """Give y-values of an ECDF for an unsorted column in a data frame.
 
@@ -2543,82 +2416,6 @@ def _ecdf_y(data, complementary=False):
         return data.rank(method="first") / len(data)
 
 
-def _point_ecdf_source(data, val, cats, cols, complementary, colored):
-    """DataFrame for making point-wise ECDF."""
-    df = data.copy()
-
-    if complementary:
-        col = "__ECCDF"
-    else:
-        col = "__ECDF"
-
-    if cats is None or colored:
-        df[col] = _ecdf_y(df[val], complementary)
-    else:
-        df[col] = df.groupby(cats)[val].transform(_ecdf_y, complementary)
-
-    cols += [col]
-
-    return _cat_source(df, cats, cols, None)
-
-
-def _ecdf_collection_dots(
-    df, val, cats, cols, complementary, order, palette, show_legend, y, p, **kwargs
-):
-    _, _, color_factors = _get_cat_range(df, df.groupby(cats), order, None, False)
-
-    source = _point_ecdf_source(df, val, cats, cols, complementary, False)
-
-    if "color" not in kwargs:
-        kwargs["color"] = bokeh.transform.factor_cmap(
-            "cat", palette=palette, factors=color_factors
-        )
-
-    if show_legend:
-        kwargs["legend"] = "__label"
-
-    p.circle(source=source, x=val, y=y, **kwargs)
-
-    return p
-
-
-def _ecdf_collection_staircase(
-    df, val, cats, complementary, order, palette, show_legend, p, **kwargs
-):
-    grouped = df.groupby(cats)
-
-    color_not_in_kwargs = "color" not in kwargs
-
-    if order is None:
-        order = list(grouped.groups.keys())
-    grouped_iterator = [
-        (order_val, grouped.get_group(order_val)) for order_val in order
-    ]
-
-    for i, g in enumerate(grouped_iterator):
-        if show_legend:
-            if type(g[0]) == tuple:
-                legend = ", ".join([str(c) for c in g[0]])
-            else:
-                legend = str(g[0])
-        else:
-            legend = None
-
-        if color_not_in_kwargs:
-            kwargs["color"] = palette[i % len(palette)]
-
-        _ecdf(
-            g[1][val],
-            staircase=True,
-            p=p,
-            legend=legend,
-            complementary=complementary,
-            **kwargs,
-        )
-
-    return p
-
-
 def _display_clicks(div, attributes=[], style="float:left;clear:left;font_size=0.5pt"):
     """Build a suitable CustomJS to display the current event
     in the div model."""
